@@ -1,5 +1,5 @@
 /* 
- *    Copyright 2015, 2016 (c) Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
+ *    Copyright 2015, 2016, 2017, 2018 (c) Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
  * 
  *    file: metadata.c
  *    This file is part of fontopia.
@@ -77,7 +77,7 @@ int save_metadata_str(struct font_s *font, int index, char *value)
   int len = strlen(value);
   if(!len) return 0;
   metadata[index].value2 = (char *)malloc(len+1);
-  char *m = metadata[index].value2;
+  //char *m = metadata[index].value2;
   if(!metadata[index].value2) return 0;
   strcpy(metadata[index].value2, value);
   return 1;
@@ -162,6 +162,7 @@ refresh:
     switch(ch)
     {
       case('s'):
+      case('S'):
 
       case(ENTER_KEY):
 	i = first_entry+selected_entry;
